@@ -513,69 +513,112 @@ namespace Model
 
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline const Aws::String& GetOwnerAlias() const{ return m_ownerAlias; }
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline void SetOwnerAlias(const Aws::String& value) { m_ownerAlias = value; }
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline void SetOwnerAlias(Aws::String&& value) { m_ownerAlias = std::move(value); }
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline void SetOwnerAlias(const char* value) { m_ownerAlias.assign(value); }
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline CreateSnapshotResponse& WithOwnerAlias(const Aws::String& value) { SetOwnerAlias(value); return *this;}
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline CreateSnapshotResponse& WithOwnerAlias(Aws::String&& value) { SetOwnerAlias(std::move(value)); return *this;}
 
     /**
-     * <p>The AWS owner alias, as maintained by Amazon. The possible values are:
-     * <code>amazon</code> | <code>self</code> | <code>all</code> |
-     * <code>aws-marketplace</code> | <code>microsoft</code>. This AWS owner alias is
-     * not to be confused with the user-configured AWS account alias, which is set from
-     * the IAM console.</p>
+     * <p>The AWS owner alias, from an Amazon-maintained list (<code>amazon</code>).
+     * This is not the user-configured AWS account alias set using the IAM console.</p>
      */
     inline CreateSnapshotResponse& WithOwnerAlias(const char* value) { SetOwnerAlias(value); return *this;}
 
 
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline const Aws::String& GetOutpostArn() const{ return m_outpostArn; }
+
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline void SetOutpostArn(const Aws::String& value) { m_outpostArn = value; }
+
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline void SetOutpostArn(Aws::String&& value) { m_outpostArn = std::move(value); }
+
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline void SetOutpostArn(const char* value) { m_outpostArn.assign(value); }
+
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline CreateSnapshotResponse& WithOutpostArn(const Aws::String& value) { SetOutpostArn(value); return *this;}
+
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline CreateSnapshotResponse& WithOutpostArn(Aws::String&& value) { SetOutpostArn(std::move(value)); return *this;}
+
+    /**
+     * <p>The ARN of the AWS Outpost on which the snapshot is stored. For more
+     * information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/snapshots-outposts.html">EBS
+     * Local Snapshot on Outposts</a> in the <i>Amazon Elastic Compute Cloud User
+     * Guide</i>.</p>
+     */
+    inline CreateSnapshotResponse& WithOutpostArn(const char* value) { SetOutpostArn(value); return *this;}
+
+
     /**
      * <p>Any tags assigned to the snapshot.</p>
      */
@@ -655,6 +698,8 @@ namespace Model
 
     Aws::String m_ownerAlias;
 
+    Aws::String m_outpostArn;
+
     Aws::Vector<Tag> m_tags;
 
     ResponseMetadata m_responseMetadata;
