@@ -1,24 +1,16 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSStreamFwd.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/ec2/model/DnsNameState.h>
 #include <aws/ec2/model/ServiceTypeDetail.h>
+#include <aws/ec2/model/PrivateDnsDetails.h>
 #include <aws/ec2/model/Tag.h>
 #include <utility>
 
@@ -349,6 +341,47 @@ namespace Model
     inline ServiceDetail& WithPrivateDnsName(const char* value) { SetPrivateDnsName(value); return *this;}
 
 
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline const Aws::Vector<PrivateDnsDetails>& GetPrivateDnsNames() const{ return m_privateDnsNames; }
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline bool PrivateDnsNamesHasBeenSet() const { return m_privateDnsNamesHasBeenSet; }
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline void SetPrivateDnsNames(const Aws::Vector<PrivateDnsDetails>& value) { m_privateDnsNamesHasBeenSet = true; m_privateDnsNames = value; }
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline void SetPrivateDnsNames(Aws::Vector<PrivateDnsDetails>&& value) { m_privateDnsNamesHasBeenSet = true; m_privateDnsNames = std::move(value); }
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline ServiceDetail& WithPrivateDnsNames(const Aws::Vector<PrivateDnsDetails>& value) { SetPrivateDnsNames(value); return *this;}
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline ServiceDetail& WithPrivateDnsNames(Aws::Vector<PrivateDnsDetails>&& value) { SetPrivateDnsNames(std::move(value)); return *this;}
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline ServiceDetail& AddPrivateDnsNames(const PrivateDnsDetails& value) { m_privateDnsNamesHasBeenSet = true; m_privateDnsNames.push_back(value); return *this; }
+
+    /**
+     * <p>The private DNS names assigned to the VPC endpoint service. </p>
+     */
+    inline ServiceDetail& AddPrivateDnsNames(PrivateDnsDetails&& value) { m_privateDnsNamesHasBeenSet = true; m_privateDnsNames.push_back(std::move(value)); return *this; }
+
+
     /**
      * <p>Indicates whether the service supports endpoint policies.</p>
      */
@@ -396,25 +429,25 @@ namespace Model
 
 
     /**
-     * <p>Indicates whether the service manages it's VPC endpoints. Management of the
+     * <p>Indicates whether the service manages its VPC endpoints. Management of the
      * service VPC endpoints using the VPC endpoint API is restricted.</p>
      */
     inline bool GetManagesVpcEndpoints() const{ return m_managesVpcEndpoints; }
 
     /**
-     * <p>Indicates whether the service manages it's VPC endpoints. Management of the
+     * <p>Indicates whether the service manages its VPC endpoints. Management of the
      * service VPC endpoints using the VPC endpoint API is restricted.</p>
      */
     inline bool ManagesVpcEndpointsHasBeenSet() const { return m_managesVpcEndpointsHasBeenSet; }
 
     /**
-     * <p>Indicates whether the service manages it's VPC endpoints. Management of the
+     * <p>Indicates whether the service manages its VPC endpoints. Management of the
      * service VPC endpoints using the VPC endpoint API is restricted.</p>
      */
     inline void SetManagesVpcEndpoints(bool value) { m_managesVpcEndpointsHasBeenSet = true; m_managesVpcEndpoints = value; }
 
     /**
-     * <p>Indicates whether the service manages it's VPC endpoints. Management of the
+     * <p>Indicates whether the service manages its VPC endpoints. Management of the
      * service VPC endpoints using the VPC endpoint API is restricted.</p>
      */
     inline ServiceDetail& WithManagesVpcEndpoints(bool value) { SetManagesVpcEndpoints(value); return *this;}
@@ -460,6 +493,49 @@ namespace Model
      */
     inline ServiceDetail& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
 
+
+    /**
+     * <p>The verification state of the VPC endpoint service.</p> <p>Consumers of the
+     * endpoint service cannot use the private name when the state is not
+     * <code>verified</code>.</p>
+     */
+    inline const DnsNameState& GetPrivateDnsNameVerificationState() const{ return m_privateDnsNameVerificationState; }
+
+    /**
+     * <p>The verification state of the VPC endpoint service.</p> <p>Consumers of the
+     * endpoint service cannot use the private name when the state is not
+     * <code>verified</code>.</p>
+     */
+    inline bool PrivateDnsNameVerificationStateHasBeenSet() const { return m_privateDnsNameVerificationStateHasBeenSet; }
+
+    /**
+     * <p>The verification state of the VPC endpoint service.</p> <p>Consumers of the
+     * endpoint service cannot use the private name when the state is not
+     * <code>verified</code>.</p>
+     */
+    inline void SetPrivateDnsNameVerificationState(const DnsNameState& value) { m_privateDnsNameVerificationStateHasBeenSet = true; m_privateDnsNameVerificationState = value; }
+
+    /**
+     * <p>The verification state of the VPC endpoint service.</p> <p>Consumers of the
+     * endpoint service cannot use the private name when the state is not
+     * <code>verified</code>.</p>
+     */
+    inline void SetPrivateDnsNameVerificationState(DnsNameState&& value) { m_privateDnsNameVerificationStateHasBeenSet = true; m_privateDnsNameVerificationState = std::move(value); }
+
+    /**
+     * <p>The verification state of the VPC endpoint service.</p> <p>Consumers of the
+     * endpoint service cannot use the private name when the state is not
+     * <code>verified</code>.</p>
+     */
+    inline ServiceDetail& WithPrivateDnsNameVerificationState(const DnsNameState& value) { SetPrivateDnsNameVerificationState(value); return *this;}
+
+    /**
+     * <p>The verification state of the VPC endpoint service.</p> <p>Consumers of the
+     * endpoint service cannot use the private name when the state is not
+     * <code>verified</code>.</p>
+     */
+    inline ServiceDetail& WithPrivateDnsNameVerificationState(DnsNameState&& value) { SetPrivateDnsNameVerificationState(std::move(value)); return *this;}
+
   private:
 
     Aws::String m_serviceName;
@@ -483,6 +559,9 @@ namespace Model
     Aws::String m_privateDnsName;
     bool m_privateDnsNameHasBeenSet;
 
+    Aws::Vector<PrivateDnsDetails> m_privateDnsNames;
+    bool m_privateDnsNamesHasBeenSet;
+
     bool m_vpcEndpointPolicySupported;
     bool m_vpcEndpointPolicySupportedHasBeenSet;
 
@@ -494,6 +573,9 @@ namespace Model
 
     Aws::Vector<Tag> m_tags;
     bool m_tagsHasBeenSet;
+
+    DnsNameState m_privateDnsNameVerificationState;
+    bool m_privateDnsNameVerificationStateHasBeenSet;
   };
 
 } // namespace Model
