@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/firehose/Firehose_EXPORTS.h>
@@ -33,6 +23,13 @@ namespace Model
     INVALID_KMS_KEY,
     KMS_KEY_NOT_FOUND,
     KMS_OPT_IN_REQUIRED,
+    CREATE_ENI_FAILED,
+    DELETE_ENI_FAILED,
+    SUBNET_NOT_FOUND,
+    SECURITY_GROUP_NOT_FOUND,
+    ENI_ACCESS_DENIED,
+    SUBNET_ACCESS_DENIED,
+    SECURITY_GROUP_ACCESS_DENIED,
     UNKNOWN_ERROR
   };
 
